@@ -53,10 +53,6 @@ from .listeners import (  # noqa
     force_auto_coercion,
     force_instant_defaults
 )
-from .materialized_view import (  # noqa
-    create_materialized_view,
-    refresh_materialized_view
-)
 from .models import generic_repr, Timestamp  # noqa
 from .observer import observes  # noqa
 from .primitives import Country, Currency, Ltree, WeekDay, WeekDays  # noqa
@@ -98,5 +94,10 @@ from .types import (  # noqa
     UUIDType,
     WeekDaysType
 )
+from .view import (  # noqa
+    create_materialized_view,
+    create_view,
+    refresh_materialized_view
+)
 
-__version__ = '0.33.1'
+__version__ = '0.34.1'
