@@ -49,37 +49,45 @@ class TestExplain(object):
 
     def test_with_string_as_stmt_param(self, assert_startswith):
         assert_startswith(
-            explain('SELECT 1 FROM article'),
+            explain(sa.text('SELECT 1 FROM article')),
             'EXPLAIN SELECT'
         )
 
     def test_format(self, assert_startswith):
         assert_startswith(
-            explain('SELECT 1 FROM article', format='json'),
+            explain(sa.text('SELECT 1 FROM article'), format='json'),
             'EXPLAIN (FORMAT json) SELECT'
         )
 
     def test_timing(self, assert_startswith):
         assert_startswith(
-            explain('SELECT 1 FROM article', analyze=True, timing=False),
+            explain(
+                sa.text('SELECT 1 FROM article'),
+                analyze=True,
+                timing=False
+            ),
             'EXPLAIN (ANALYZE true, TIMING false) SELECT'
         )
 
     def test_verbose(self, assert_startswith):
         assert_startswith(
-            explain('SELECT 1 FROM article', verbose=True),
+            explain(sa.text('SELECT 1 FROM article'), verbose=True),
             'EXPLAIN (VERBOSE true) SELECT'
         )
 
     def test_buffers(self, assert_startswith):
         assert_startswith(
-            explain('SELECT 1 FROM article', analyze=True, buffers=True),
+            explain(
+                sa.text('SELECT 1 FROM article'),
+                analyze=True,
+                buffers=True
+            ),
             'EXPLAIN (ANALYZE true, BUFFERS true) SELECT'
         )
 
     def test_costs(self, assert_startswith):
         assert_startswith(
-            explain('SELECT 1 FROM article', costs=False),
+            explain(sa.text('SELECT 1 FROM article'), costs=False),
             'EXPLAIN (COSTS false) SELECT'
         )
 
@@ -118,8 +126,9 @@ class TestAsterisk(object):
 
 class TestRowToJson(object):
     def test_compiler_with_default_dialect(self):
-        with pytest.raises(sa.exc.CompileError):
-            str(row_to_json(sa.text('article.*')))
+        assert str(row_to_json(sa.text('article.*'))) == (
+            'row_to_json(article.*)'
+        )
 
     def test_compiler_with_postgresql(self):
         assert str(row_to_json(sa.text('article.*')).compile(
@@ -131,34 +140,3 @@ class TestRowToJson(object):
             sa.func.row_to_json(sa.text('article.*')).type,
             postgresql.JSON
         )
-
-
-class TestArrayAgg(object):
-    def test_compiler_with_default_dialect(self):
-        with pytest.raises(sa.exc.CompileError):
-            str(sa.func.array_agg(sa.text('u.name')))
-
-    def test_compiler_with_postgresql(self):
-        assert str(sa.func.array_agg(sa.text('u.name')).compile(
-            dialect=postgresql.dialect()
-        )) == "array_agg(u.name)"
-
-    def test_type(self):
-        assert isinstance(
-            sa.func.array_agg(sa.text('u.name')).type,
-            postgresql.ARRAY
-        )
-
-    def test_array_agg_with_default(self):
-        Base = sa.ext.declarative.declarative_base()
-
-        class Article(Base):
-            __tablename__ = 'article'
-            id = sa.Column(sa.Integer, primary_key=True)
-
-        assert str(sa.func.array_agg(Article.id, [1]).compile(
-            dialect=postgresql.dialect()
-        )) == (
-            'coalesce(array_agg(article.id), CAST(ARRAY[%(param_1)s]'
-            ' AS INTEGER[]))'
-        )
